@@ -1,16 +1,16 @@
+import re
 import sys
 
 
-def test_simple_invocation(get_cli_invocation):
-    result = get_cli_invocation(
+def test_simple_invocation(run_subprocess):
+    result = run_subprocess(
         sys.executable,
         '-m',
         'cookiecutter_python',
         '--help',
     )
     assert result.exit_code == 0
-    print(result.stdout)
-    assert result.stdout.split('\n')[0] == 'Usage: generate-python [OPTIONS]'
+    assert re.match(r'Usage: generate\-python \[OPTIONS\]', result.stdout.split('\n')[0])
     assert result.stderr == ''
 
 
